@@ -3,6 +3,9 @@ from django.contrib import messages
 
 
 def izitoast(request, model, message, diversify=None):
+    if type(message) == str:
+        message = str_to_dict(model=model, message=message)
+
     template = None
     create_content = None
     if model == "success":
@@ -24,7 +27,7 @@ def izitoast(request, model, message, diversify=None):
         create_content = render_to_string(template_name=template, context=message)
         create_content += render_to_string(template_name='custom_response/diversify.txt',
                                            context=diversify)
-    print(create_content)
+
     if model == "success":
         return messages.success(request=request, message=create_content)
     elif model == "info":
@@ -35,3 +38,15 @@ def izitoast(request, model, message, diversify=None):
         return messages.error(request=request, message=create_content)
     elif model == "form-error":
         return messages.error(request=request, message=create_content)
+
+
+def str_to_dict(model, message):
+    message_dict = {
+        'raw': [
+            {
+                'tag': model,
+                'item': message
+            }
+        ]
+    }
+    return message_dict
